@@ -2,14 +2,18 @@
 # Concatenation classes
 #
 import copy
-import numpy as np
-import pybamm
-from scipy.sparse import vstack
 from collections import defaultdict
 
+import numpy as np
+import sympy
+from scipy.sparse import issparse, vstack
+
+import pybamm
+
 
 class Concatenation(pybamm.Symbol):
-    """A node in the expression tree representing a concatenation of symbols
+    """
+    A node in the expression tree representing a concatenation of symbols.
 
     **Extends**: :class:`pybamm.Symbol`
 
@@ -17,10 +21,20 @@ class Concatenation(pybamm.Symbol):
     ----------
     children : iterable of :class:`pybamm.Symbol`
         The symbols to concatenate
-
     """
 
     def __init__(self, *children, name=None, check_domain=True, concat_fun=None):
+        # The second condition checks whether this is the base Concatenation class
+        # or a subclass of Concatenation
+        # (ConcatenationVariable, NumpyConcatenation, ...)
+        if all(isinstance(child, pybamm.Variable) for child in children) and issubclass(
+            Concatenation, type(self)
+        ):
+            raise TypeError(
+                "'ConcatenationVariable' should be used for concatenating 'Variable' "
+                "objects. We recommend using the 'concatenation' function, which will "
+                "automatically choose the best form."
+            )
         if name is None:
             name = "concatenation"
         if check_domain:
@@ -34,6 +48,24 @@ class Concatenation(pybamm.Symbol):
             name, children, domain=domain, auxiliary_domains=auxiliary_domains
         )
 
+    def __str__(self):
+        """See :meth:`pybamm.Symbol.__str__()`."""
+        out = self.name + "("
+        for child in self.children:
+            out += "{!s}, ".format(child)
+        out = out[:-2] + ")"
+        return out
+
+    def _diff(self, variable):
+        """See :meth:`pybamm.Symbol._diff()`."""
+        children_diffs = [child.diff(variable) for child in self.cached_children]
+        if len(children_diffs) == 1:
+            diff = children_diffs[0]
+        else:
+            diff = self.__class__(*children_diffs)
+
+        return diff
+
     def get_children_domains(self, children):
         # combine domains from children
         domain = []
@@ -41,21 +73,25 @@ class Concatenation(pybamm.Symbol):
             if not isinstance(child, pybamm.Symbol):
                 raise TypeError("{} is not a pybamm symbol".format(child))
             child_domain = child.domain
+            if child_domain == []:
+                raise pybamm.DomainError(
+                    "Cannot concatenate child '{}' with empty domain".format(child)
+                )
             if set(domain).isdisjoint(child_domain):
                 domain += child_domain
             else:
-                raise pybamm.DomainError("""domain of children must be disjoint""")
+                raise pybamm.DomainError("domain of children must be disjoint")
         return domain
 
     def _concatenation_evaluate(self, children_eval):
-        """ See :meth:`Concatenation._concatenation_evaluate()`. """
+        """See :meth:`Concatenation._concatenation_evaluate()`."""
         if len(children_eval) == 0:
             return np.array([])
         else:
             return self.concatenation_function(children_eval)
 
     def evaluate(self, t=None, y=None, y_dot=None, inputs=None, known_evals=None):
-        """ See :meth:`pybamm.Symbol.evaluate()`. """
+        """See :meth:`pybamm.Symbol.evaluate()`."""
         children = self.cached_children
         if known_evals is not None:
             if self.id not in known_evals:
@@ -72,28 +108,21 @@ class Concatenation(pybamm.Symbol):
                 children_eval[idx] = child.evaluate(t, y, y_dot, inputs)
             return self._concatenation_evaluate(children_eval)
 
-    def new_copy(self):
-        """ See :meth:`pybamm.Symbol.new_copy()`. """
+    def create_copy(self):
+        """See :meth:`pybamm.Symbol.new_copy()`."""
         new_children = [child.new_copy() for child in self.children]
         return self._concatenation_new_copy(new_children)
 
     def _concatenation_new_copy(self, children):
-        """ See :meth:`pybamm.Symbol.new_copy()`. """
-        new_symbol = self.__class__(*children)
-        return new_symbol
+        """See :meth:`pybamm.Symbol.new_copy()`."""
+        return concatenation(*children)
 
     def _concatenation_jac(self, children_jacs):
-        """ Calculate the jacobian of a concatenation """
+        """Calculate the jacobian of a concatenation."""
         return NotImplementedError
 
-    def _concatenation_simplify(self, children):
-        """ See :meth:`pybamm.Symbol.simplify()`. """
-        new_symbol = self.__class__(*children)
-        new_symbol.clear_domains()
-        return new_symbol
-
     def _evaluate_for_shape(self):
-        """ See :meth:`pybamm.Symbol.evaluate_for_shape` """
+        """See :meth:`pybamm.Symbol.evaluate_for_shape`"""
         if len(self.children) == 0:
             return np.array([])
         else:
@@ -103,9 +132,33 @@ class Concatenation(pybamm.Symbol):
                 [child.evaluate_for_shape() for child in self.children]
             )
 
+    def is_constant(self):
+        """See :meth:`pybamm.Symbol.is_constant()`."""
+        return all(child.is_constant() for child in self.children)
+
+    def _sympy_operator(self, *children):
+        """Apply appropriate SymPy operators."""
+        self.concat_latex = tuple(map(sympy.latex, children))
+
+        if self.print_name is not None:
+            return sympy.Symbol(self.print_name)
+        else:
+            concat_str = r"\\".join(self.concat_latex)
+            concat_sym = sympy.Symbol(r"\begin{cases}" + concat_str + r"\end{cases}")
+            return concat_sym
+
+    def to_equation(self):
+        """Convert the node and its subtree into a SymPy equation."""
+        eq_list = []
+        for child in self.children:
+            eq = child.to_equation()
+            eq_list.append(eq)
+        return self._sympy_operator(*eq_list)
+
 
 class NumpyConcatenation(Concatenation):
-    """A node in the expression tree representing a concatenation of equations, when we
+    """
+    A node in the expression tree representing a concatenation of equations, when we
     *don't* care about domains. The class :class:`pybamm.DomainConcatenation`, which
     *is* careful about domains and uses broadcasting where appropriate, should be used
     whenever possible instead.
@@ -118,7 +171,6 @@ class NumpyConcatenation(Concatenation):
     ----------
     children : iterable of :class:`pybamm.Symbol`
         The equations to concatenate
-
     """
 
     def __init__(self, *children):
@@ -130,36 +182,27 @@ class NumpyConcatenation(Concatenation):
                 children[i] = child * pybamm.Vector([1])
         super().__init__(
             *children,
-            name="numpy concatenation",
+            name="numpy_concatenation",
             check_domain=False,
             concat_fun=np.concatenate
         )
 
     def _concatenation_jac(self, children_jacs):
-        """ See :meth:`pybamm.Concatenation.concatenation_jac()`. """
+        """See :meth:`pybamm.Concatenation.concatenation_jac()`."""
         children = self.cached_children
         if len(children) == 0:
             return pybamm.Scalar(0)
         else:
             return SparseStack(*children_jacs)
 
-    def _concatenation_simplify(self, children):
-        """ See :meth:`pybamm.Symbol.simplify()`. """
-        # Turn a concatenation of concatenations into a single concatenation
-        new_children = []
-        for child in children:
-            # extract any children from numpy concatenation
-            if isinstance(child, NumpyConcatenation):
-                new_children.extend(child.orphans)
-            else:
-                new_children.append(child)
-        new_symbol = NumpyConcatenation(*new_children)
-        new_symbol.clear_domains()
-        return new_symbol
+    def _concatenation_new_copy(self, children):
+        """See :meth:`pybamm.Symbol.new_copy()`."""
+        return numpy_concatenation(*children)
 
 
 class DomainConcatenation(Concatenation):
-    """A node in the expression tree representing a concatenation of symbols, being
+    """
+    A node in the expression tree representing a concatenation of symbols, being
     careful about domains.
 
     It is assumed that each child has a domain, and the final concatenated vector will
@@ -180,7 +223,6 @@ class DomainConcatenation(Concatenation):
     copy_this : :class:`pybamm.DomainConcatenation` (optional)
         if provided, this class is initialised by copying everything except the children
         from `copy_this`. `mesh` is not used in this case
-
     """
 
     def __init__(self, children, full_mesh, copy_this=None):
@@ -189,7 +231,7 @@ class DomainConcatenation(Concatenation):
         children = list(children)
 
         # Allow the base class to sort the domains into the correct order
-        super().__init__(*children, name="domain concatenation")
+        super().__init__(*children, name="domain_concatenation")
 
         # ensure domain is sorted according to mesh keys
         domain_dict = {d: full_mesh.domain_order.index(d) for d in self.domain}
@@ -199,16 +241,6 @@ class DomainConcatenation(Concatenation):
             # store mesh
             self._full_mesh = full_mesh
 
-            # Check that there is a domain, otherwise the functionality won't work
-            # and we should raise a DomainError
-            if self.domain == []:
-                raise pybamm.DomainError(
-                    """
-                    domain cannot be empty for a DomainConcatenation.
-                    Perhaps the children should have been Broadcasted first?
-                    """
-                )
-
             # create dict of domain => slice of final vector
             self.secondary_dimensions_npts = self._get_auxiliary_domain_repeats(
                 self.domains
@@ -230,9 +262,7 @@ class DomainConcatenation(Concatenation):
             self.secondary_dimensions_npts = copy_this.secondary_dimensions_npts
 
     def _get_auxiliary_domain_repeats(self, auxiliary_domains):
-        """
-        Helper method to read the 'auxiliary_domain' meshes
-        """
+        """Helper method to read the 'auxiliary_domain' meshes."""
         if "secondary" in auxiliary_domains:
             sec_mesh_npts = self.full_mesh.combine_submeshes(
                 *auxiliary_domains["secondary"]
@@ -269,7 +299,7 @@ class DomainConcatenation(Concatenation):
         return slices
 
     def _concatenation_evaluate(self, children_eval):
-        """ See :meth:`Concatenation._concatenation_evaluate()`. """
+        """See :meth:`Concatenation._concatenation_evaluate()`."""
         # preallocate vector
         vector = np.empty((self._size, 1))
 
@@ -282,7 +312,7 @@ class DomainConcatenation(Concatenation):
         return vector
 
     def _concatenation_jac(self, children_jacs):
-        """ See :meth:`pybamm.Concatenation.concatenation_jac()`. """
+        """See :meth:`pybamm.Concatenation.concatenation_jac()`."""
         # note that this assumes that the children are in the right order and only have
         # one domain each
         jacs = []
@@ -298,40 +328,16 @@ class DomainConcatenation(Concatenation):
         return SparseStack(*jacs)
 
     def _concatenation_new_copy(self, children):
-        """ See :meth:`pybamm.Symbol.new_copy()`. """
-        new_symbol = self.__class__(children, self.full_mesh, self)
-        return new_symbol
-
-    def _concatenation_simplify(self, children):
-        """ See :meth:`pybamm.Symbol.simplify()`. """
-        # Simplify Concatenation of StateVectors to a single StateVector
-        # The sum of the evalation arrays of the StateVectors must be exactly 1
-        if all([isinstance(child, pybamm.StateVector) for child in children]):
-            longest_eval_array = len(children[-1]._evaluation_array)
-            eval_arrays = {}
-            for child in children:
-                eval_arrays[child] = np.concatenate(
-                    [
-                        child.evaluation_array,
-                        np.zeros(longest_eval_array - len(child.evaluation_array)),
-                    ]
-                )
-            if all(sum(array for array in eval_arrays.values()) == 1):
-                return pybamm.StateVector(
-                    slice(children[0].y_slices[0].start, children[-1].y_slices[-1].stop)
-                )
-
-        new_symbol = self.__class__(children, self.full_mesh, self)
-
-        # TODO: this should not be needed, but somehow we are still getting domains in
-        # the simplified children
-        new_symbol.clear_domains()
-
+        """See :meth:`pybamm.Symbol.new_copy()`."""
+        new_symbol = simplified_domain_concatenation(
+            children, self.full_mesh, copy_this=self
+        )
         return new_symbol
 
 
 class SparseStack(Concatenation):
-    """A node in the expression tree representing a concatenation of sparse
+    """
+    A node in the expression tree representing a concatenation of sparse
     matrices. As with NumpyConcatenation, we *don't* care about domains.
     The class :class:`pybamm.DomainConcatenation`, which *is* careful about
     domains and uses broadcasting where appropriate, should be used whenever
@@ -343,11 +349,160 @@ class SparseStack(Concatenation):
     ----------
     children : iterable of :class:`Concatenation`
         The equations to concatenate
-
     """
 
     def __init__(self, *children):
         children = list(children)
+        if not any(issparse(child.evaluate_for_shape()) for child in children):
+            concatenation_function = np.vstack
+        else:
+            concatenation_function = vstack
         super().__init__(
-            *children, name="sparse stack", check_domain=False, concat_fun=vstack
+            *children,
+            name="sparse_stack",
+            check_domain=False,
+            concat_fun=concatenation_function
         )
+
+    def _concatenation_new_copy(self, children):
+        """See :meth:`pybamm.Symbol.new_copy()`."""
+        return SparseStack(*children)
+
+
+class ConcatenationVariable(Concatenation):
+    """A Variable representing a concatenation of variables."""
+
+    def __init__(self, *children):
+        # Name is the intersection of the children names (should usually make sense
+        # if the children have been named consistently)
+        name = intersect(children[0].name, children[1].name)
+        for child in children[2:]:
+            name = intersect(name, child.name)
+        name = name.capitalize()
+        if name == "":
+            name = None
+        super().__init__(*children, name=name)
+        # Overly tight bounds, can edit later if required
+        self.bounds = (
+            np.max([child.bounds[0] for child in children]),
+            np.min([child.bounds[1] for child in children]),
+        )
+
+        if not any(c.print_name is None for c in children):
+            print_name = intersect(children[0].print_name, children[1].print_name)
+            for child in children[2:]:
+                print_name = intersect(print_name, child.print_name)
+            if print_name.endswith("_"):
+                print_name = print_name[:-1]
+        else:
+            print_name = None
+        self.print_name = print_name
+
+
+def substrings(s):
+    for i in range(len(s)):
+        for j in range(i, len(s)):
+            yield s[i : j + 1]
+
+
+def intersect(s1, s2):
+    # find all the common strings between two strings
+    all_intersects = set(substrings(s1)) & set(substrings(s2))
+    # intersect is the longest such intercept
+    if len(all_intersects) == 0:
+        return ""
+    intersect = max(all_intersects, key=len)
+    # remove leading and trailing white space
+    return intersect.lstrip().rstrip()
+
+
+def simplified_concatenation(*children):
+    """Perform simplifications on a concatenation."""
+    # remove children that are None
+    children = list(filter(lambda x: x is not None, children))
+    # Simplify concatenation of broadcasts all with the same child to a single
+    # broadcast across all domains
+    if len(children) == 0:
+        raise ValueError("Cannot create empty concatenation")
+    elif len(children) == 1:
+        return children[0]
+    elif all(isinstance(child, pybamm.Variable) for child in children):
+        return pybamm.ConcatenationVariable(*children)
+    else:
+        # Create Concatenation to easily read domains
+        concat = Concatenation(*children)
+        if all(
+            isinstance(child, pybamm.Broadcast)
+            and child.child.id == children[0].child.id
+            for child in children
+        ):
+            unique_child = children[0].orphans[0]
+            if isinstance(children[0], pybamm.PrimaryBroadcast):
+                return pybamm.PrimaryBroadcast(unique_child, concat.domain)
+            else:
+                return pybamm.FullBroadcast(
+                    unique_child, concat.domain, concat.auxiliary_domains
+                )
+        else:
+            return concat
+
+
+def concatenation(*children):
+    """Helper function to create concatenations."""
+    # TODO: add option to turn off simplifications
+    return simplified_concatenation(*children)
+
+
+def simplified_numpy_concatenation(*children):
+    """Perform simplifications on a numpy concatenation."""
+    # Turn a concatenation of concatenations into a single concatenation
+    new_children = []
+    for child in children:
+        # extract any children from numpy concatenation
+        if isinstance(child, NumpyConcatenation):
+            new_children.extend(child.orphans)
+        else:
+            new_children.append(child)
+    return pybamm.simplify_if_constant(NumpyConcatenation(*new_children))
+
+
+def numpy_concatenation(*children):
+    """Helper function to create numpy concatenations."""
+    # TODO: add option to turn off simplifications
+    return simplified_numpy_concatenation(*children)
+
+
+def simplified_domain_concatenation(children, mesh, copy_this=None):
+    """Perform simplifications on a domain concatenation."""
+    # Create the DomainConcatenation to read domain and child domain
+    concat = DomainConcatenation(children, mesh, copy_this=copy_this)
+    # Simplify Concatenation of StateVectors to a single StateVector
+    # The sum of the evalation arrays of the StateVectors must be exactly 1
+    if all(isinstance(child, pybamm.StateVector) for child in children):
+        longest_eval_array = len(children[-1]._evaluation_array)
+        eval_arrays = {}
+        for child in children:
+            eval_arrays[child] = np.concatenate(
+                [
+                    child.evaluation_array,
+                    np.zeros(longest_eval_array - len(child.evaluation_array)),
+                ]
+            )
+        first_start = children[0].y_slices[0].start
+        last_stop = children[-1].y_slices[-1].stop
+        if all(
+            sum(array for array in eval_arrays.values())[first_start:last_stop] == 1
+        ):
+            return pybamm.StateVector(
+                slice(first_start, last_stop),
+                domain=concat.domain,
+                auxiliary_domains=concat.auxiliary_domains,
+            )
+
+    return pybamm.simplify_if_constant(concat)
+
+
+def domain_concatenation(children, mesh):
+    """Helper function to create domain concatenations."""
+    # TODO: add option to turn off simplifications
+    return simplified_domain_concatenation(children, mesh)
