@@ -2,12 +2,15 @@
 # Parameter classes
 #
 import numbers
+
 import numpy as np
+
 import pybamm
 
 
 class InputParameter(pybamm.Symbol):
-    """A node in the expression tree representing an input parameter
+    """
+    A node in the expression tree representing an input parameter.
 
     This node's value can be set at the point of solving, allowing parameter estimation
     and control
@@ -26,25 +29,33 @@ class InputParameter(pybamm.Symbol):
         self._expected_size = 1
         super().__init__(name, domain=domain)
 
-    def new_copy(self):
-        """ See :meth:`pybamm.Symbol.new_copy()`. """
+    def create_copy(self):
+        """See :meth:`pybamm.Symbol.new_copy()`."""
         new_input_parameter = InputParameter(self.name, self.domain)
         new_input_parameter._expected_size = self._expected_size
         return new_input_parameter
 
     def set_expected_size(self, size):
-        "Specify the size that the input parameter should be"
+        """Specify the size that the input parameter should be."""
         self._expected_size = size
 
+        # We also need to update the saved size and shape
+        self._saved_size = size
+        self._saved_shape = (size, 1)
+        self._saved_evaluate_for_shape = self._evaluate_for_shape()
+
     def _evaluate_for_shape(self):
         """
         Returns the scalar 'NaN' to represent the shape of a parameter.
         See :meth:`pybamm.Symbol.evaluate_for_shape()`
         """
-        return np.nan * np.ones((self._expected_size, 1))
+        if self._expected_size == 1:
+            return np.nan
+        else:
+            return np.nan * np.ones((self._expected_size, 1))
 
     def _jac(self, variable):
-        """ See :meth:`pybamm.Symbol._jac()`. """
+        """See :meth:`pybamm.Symbol._jac()`."""
         return pybamm.Scalar(0)
 
     def _base_evaluate(self, t=None, y=None, y_dot=None, inputs=None):
@@ -53,9 +64,9 @@ class InputParameter(pybamm.Symbol):
         if inputs is None:
             inputs = {}
         if not isinstance(inputs, dict):
-            # if the special input "shape test" is passed, just return 1
+            # if the special input "shape test" is passed, just return NaN
             if inputs == "shape test":
-                return np.ones((self._expected_size, 1))
+                return self.evaluate_for_shape()
             raise TypeError("inputs should be a dictionary")
         try:
             input_eval = inputs[self.name]
