@@ -1,16 +1,17 @@
 #
 # Matrix class
 #
-import pybamm
 import numpy as np
-from scipy.sparse import issparse
+from scipy.sparse import csr_matrix, issparse
+
+import pybamm
 
 
 class Matrix(pybamm.Array):
-    """node in the expression tree that holds a matrix type (e.g. :class:`numpy.array`)
+    """
+    Node in the expression tree that holds a matrix type (e.g. :class:`numpy.array`)
 
     **Extends:** :class:`Array`
-
     """
 
     def __init__(
@@ -27,4 +28,7 @@ class Matrix(pybamm.Array):
             name = "Matrix {!s}".format(entries.shape)
             if issparse(entries):
                 name = "Sparse " + name
+        # Convert all sparse matrices to csr
+        if issparse(entries) and not isinstance(entries, csr_matrix):
+            entries = csr_matrix(entries)
         super().__init__(entries, name, domain, auxiliary_domains, entries_string)
