@@ -33,19 +33,24 @@ class Geometry(dict):
         super().__init__(**geometry)
         self._parameters = None
 
+    def print_parameter_info(self):
+        "Prints all the parameters' information"
+        for param in self.parameters:
+            print(param.name + " (Parameter)")
+
     @property
     def parameters(self):
-        "Returns all the parameters in the geometry"
+        """Returns all the parameters in the geometry"""
         if self._parameters is None:
             self._parameters = self._find_parameters()
         return self._parameters
 
     def _find_parameters(self):
-        "Find all the parameters in the model"
+        """Find all the parameters in the model"""
         unpacker = pybamm.SymbolUnpacker((pybamm.Parameter, pybamm.InputParameter))
 
         def NestedDictValues(d):
-            "Get all the values from a nested dict"
+            """Get all the values from a nested dict"""
             for v in d.values():
                 if isinstance(v, dict):
                     yield from NestedDictValues(v)
