@@ -30,6 +30,9 @@ x = pybamm.SpatialVariable(
 
 y = pybamm.SpatialVariable("y", domain="current collector", coord_sys="cartesian")
 z = pybamm.SpatialVariable("z", domain="current collector", coord_sys="cartesian")
+r_macro = pybamm.SpatialVariable(
+    "r_macro", domain="current collector", coord_sys="cylindrical polar"
+)
 
 r_n = pybamm.SpatialVariable(
     "r_n",
@@ -101,6 +104,10 @@ y_edge = pybamm.SpatialVariableEdge(
 z_edge = pybamm.SpatialVariableEdge(
     "z", domain="current collector", coord_sys="cartesian"
 )
+r_macro_edge = pybamm.SpatialVariableEdge(
+    "r_macro", domain="current collector", coord_sys="cylindrical polar"
+)
+
 
 r_n_edge = pybamm.SpatialVariableEdge(
     "r_n",
