@@ -1,13 +1,16 @@
 #
 # Class for quick plotting of variables from models
 #
+import os
 import numpy as np
 import pybamm
 from collections import defaultdict
 
 
 class LoopList(list):
-    "A list which loops over itself when accessing an index so that it never runs out."
+
+    """A list which loops over itself when accessing an
+    index so that it never runs out"""
 
     def __getitem__(self, i):
         # implement looping by calling "(i) modulo (length of list)"
@@ -15,25 +18,22 @@ class LoopList(list):
 
 
 def ax_min(data):
-    "Calculate appropriate minimum axis value for plotting"
+    """Calculate appropriate minimum axis value for plotting"""
     data_min = np.nanmin(data)
-    if data_min <= 0:
-        return 1.04 * data_min
-    else:
-        return 0.96 * data_min
+    data_max = np.nanmax(data)
+    return data_max - 1.05 * (data_max - data_min)
 
 
 def ax_max(data):
-    "Calculate appropriate maximum axis value for plotting"
+    """Calculate appropriate maximum axis value for plotting"""
+    data_min = np.nanmin(data)
     data_max = np.nanmax(data)
-    if data_max <= 0:
-        return 0.96 * data_max
-    else:
-        return 1.04 * data_max
+    return data_min + 1.05 * (data_max - data_min)
 
 
-def split_long_string(title, max_words=4):
-    "Get title in a nice format"
+def split_long_string(title, max_words=None):
+    """Get title in a nice format"""
+    max_words = max_words or pybamm.settings.max_words_in_line
     words = title.split()
     # Don't split if fits on one line, don't split just for units
     if len(words) <= max_words or words[max_words].startswith("["):
@@ -45,7 +45,7 @@ def split_long_string(title, max_words=4):
 
 
 def close_plots():
-    "Close all open figures"
+    """Close all open figures"""
     import matplotlib.pyplot as plt
 
     plt.close("all")
@@ -66,16 +66,19 @@ class QuickPlot(object):
     labels : list of str, optional
         Labels for the different models. Defaults to model names
     colors : list of str, optional
-        The colors to loop over when plotting. Defaults to
-        ["r", "b", "k", "g", "m", "c"]
+        The colors to loop over when plotting. Defaults to None, in which case the
+        default color loop defined by matplotlib style sheet or rcParams is used.
     linestyles : list of str, optional
         The linestyles to loop over when plotting. Defaults to ["-", ":", "--", "-."]
     figsize : tuple of floats, optional
         The size of the figure to make
+    n_rows : int, optional
+        The number of rows to use. If None (default), floor(n // sqrt(n)) is used where
+        n = len(output_variables) so that the plot is as square as possible
     time_unit : str, optional
-        Format for the time output ("hours", "minutes" or "seconds")
+        Format for the time output ("hours", "minutes", or "seconds")
     spatial_unit : str, optional
-        Format for the spatial axes ("m", "mm" or "um")
+        Format for the spatial axes ("m", "mm", or "um")
     variable_limits : str or dict of str, optional
         How to set the axis limits (for 0D or 1D variables) or colorbar limits (for 2D
         variables). Options are:
@@ -95,25 +98,28 @@ class QuickPlot(object):
         colors=None,
         linestyles=None,
         figsize=None,
+        n_rows=None,
         time_unit=None,
         spatial_unit="um",
         variable_limits="fixed",
     ):
-        if isinstance(solutions, (pybamm.Solution, pybamm.Simulation)):
-            solutions = [solutions]
-        elif not isinstance(solutions, list):
+        input_solutions = solutions
+        solutions = []
+        if not isinstance(input_solutions, (pybamm.Solution, pybamm.Simulation, list)):
             raise TypeError(
                 "solutions must be 'pybamm.Solution' or 'pybamm.Simulation' or list"
             )
+        elif not isinstance(input_solutions, list):
+            input_solutions = [input_solutions]
+        for sim_or_sol in input_solutions:
+            if isinstance(sim_or_sol, pybamm.Simulation):
+                # 'sim_or_sol' is actually a 'Simulation' object here so it has a
+                # 'Solution' attribute
+                solutions.append(sim_or_sol.solution)
+            elif isinstance(sim_or_sol, pybamm.Solution):
+                solutions.append(sim_or_sol)
 
-        # Extract solution from any simulations
-        for idx, sol in enumerate(solutions):
-            if isinstance(sol, pybamm.Simulation):
-                # 'sol' is actually a 'Simulation' object here so it has a 'Solution'
-                # attribute
-                solutions[idx] = sol.solution
-
-        models = [solution.model for solution in solutions]
+        models = [solution.all_models[0] for solution in solutions]
 
         # Set labels
         if labels is None:
@@ -129,9 +135,29 @@ class QuickPlot(object):
 
         # Set colors, linestyles, figsize, axis limits
         # call LoopList to make sure list index never runs out
-        self.colors = LoopList(colors or ["r", "b", "k", "g", "m", "c"])
+        if colors is None:
+            self.colors = LoopList(colors or ["r", "b", "k", "g", "m", "c"])
+        else:
+            self.colors = LoopList(colors)
         self.linestyles = LoopList(linestyles or ["-", ":", "--", "-."])
-        self.figsize = figsize or (15, 8)
+
+        # Default output variables for lead-acid and lithium-ion
+        if output_variables is None:
+            output_variables = models[0].default_quick_plot_variables
+            # raise error if still None
+            if output_variables is None:
+                raise ValueError(
+                    f"No default output variables provided for {models[0].name}"
+                )
+
+        self.n_rows = n_rows or int(
+            len(output_variables) // np.sqrt(len(output_variables))
+        )
+        self.n_cols = int(np.ceil(len(output_variables) / self.n_rows))
+
+        figwidth_default = min(15, 4 * self.n_cols)
+        figheight_default = min(8, 1 + 3 * self.n_rows)
+        self.figsize = figsize or (figwidth_default, figheight_default)
 
         # Spatial scales (default to 1 if information not in model)
         if spatial_unit == "m":
@@ -142,20 +168,13 @@ class QuickPlot(object):
             self.spatial_unit = "mm"
         elif spatial_unit == "um":  # micrometers
             self.spatial_factor = 1e6
-            self.spatial_unit = "$\mu m$"
+            self.spatial_unit = "$\mu$m"
         else:
             raise ValueError("spatial unit '{}' not recognized".format(spatial_unit))
 
-        # Set length scales
-        self.length_scales = {
-            domain: scale.evaluate() * self.spatial_factor
-            for domain, scale in models[0].length_scales.items()
-        }
-
         # Time parameters
-        model_timescale_in_seconds = models[0].timescale_eval
         self.ts_seconds = [
-            solution.t * model_timescale_in_seconds for solution in solutions
+            solution.t * solution.timescale_eval for solution in solutions
         ]
         min_t = np.min([t[0] for t in self.ts_seconds])
         max_t = np.max([t[-1] for t in self.ts_seconds])
@@ -184,29 +203,6 @@ class QuickPlot(object):
         self.min_t = min_t / time_scaling_factor
         self.max_t = max_t / time_scaling_factor
 
-        # Default output variables for lead-acid and lithium-ion
-        if output_variables is None:
-            if isinstance(models[0], pybamm.lithium_ion.BaseModel):
-                output_variables = [
-                    "Negative particle surface concentration [mol.m-3]",
-                    "Electrolyte concentration [mol.m-3]",
-                    "Positive particle surface concentration [mol.m-3]",
-                    "Current [A]",
-                    "Negative electrode potential [V]",
-                    "Electrolyte potential [V]",
-                    "Positive electrode potential [V]",
-                    "Terminal voltage [V]",
-                ]
-            elif isinstance(models[0], pybamm.lead_acid.BaseModel):
-                output_variables = [
-                    "Interfacial current density [A.m-2]",
-                    "Electrolyte concentration [mol.m-3]",
-                    "Current [A]",
-                    "Porosity",
-                    "Electrolyte potential [V]",
-                    "Terminal voltage [V]",
-                ]
-
         # Prepare dictionary of variables
         # output_variables is a list of strings or lists, e.g.
         # ["var 1", ["variable 2", "var 3"]]
@@ -250,13 +246,11 @@ class QuickPlot(object):
         self.spatial_variable_dict = {}
         self.first_dimensional_spatial_variable = {}
         self.second_dimensional_spatial_variable = {}
-        self.is_x_r = {}
+        self.x_first_and_y_second = {}
         self.is_y_z = {}
 
         # Calculate subplot positions based on number of variables supplied
         self.subplot_positions = {}
-        self.n_rows = int(len(output_variables) // np.sqrt(len(output_variables)))
-        self.n_cols = int(np.ceil(len(output_variables) / self.n_rows))
 
         for k, variable_tuple in enumerate(output_variables):
             # Prepare list of variables
@@ -334,16 +328,21 @@ class QuickPlot(object):
                     self.second_dimensional_spatial_variable[variable_tuple] = (
                         second_spatial_var_value * self.spatial_factor
                     )
-                    if first_spatial_var_name == "r" and second_spatial_var_name == "x":
-                        self.is_x_r[variable_tuple] = True
+                    # different order based on whether the domains
+                    # are x-r, x-z or y-z, etc
+                    if (
+                        first_spatial_var_name in ("r", "R")
+                        and second_spatial_var_name == "x"
+                    ):
+                        self.x_first_and_y_second[variable_tuple] = False
                         self.is_y_z[variable_tuple] = False
                     elif (
                         first_spatial_var_name == "y" and second_spatial_var_name == "z"
                     ):
-                        self.is_x_r[variable_tuple] = False
+                        self.x_first_and_y_second[variable_tuple] = True
                         self.is_y_z[variable_tuple] = True
                     else:
-                        self.is_x_r[variable_tuple] = False
+                        self.x_first_and_y_second[variable_tuple] = True
                         self.is_y_z[variable_tuple] = False
 
             # Store variables and subplot position
@@ -351,7 +350,7 @@ class QuickPlot(object):
             self.subplot_positions[variable_tuple] = (self.n_rows, self.n_cols, k + 1)
 
     def get_spatial_var(self, key, variable, dimension):
-        "Return the appropriate spatial variable(s)"
+        """Return the appropriate spatial variable(s)"""
 
         # Extract name and dimensionless value
         # Special case for current collector, which is 2D but in a weird way (both
@@ -388,8 +387,8 @@ class QuickPlot(object):
                 x_min = self.first_dimensional_spatial_variable[key][0]
                 x_max = self.first_dimensional_spatial_variable[key][-1]
             elif variable_lists[0][0].dimensions == 2:
-                # different order based on whether the domains are x-r, x-z or y-z
-                if self.is_x_r[key] is True:
+                # different order based on whether the domains are x-r, x-z or y-z, etc
+                if self.x_first_and_y_second[key] is False:
                     x_min = self.second_dimensional_spatial_variable[key][0]
                     x_max = self.second_dimensional_spatial_variable[key][-1]
                     y_min = self.first_dimensional_spatial_variable[key][0]
@@ -421,6 +420,11 @@ class QuickPlot(object):
                         for var in variable_list
                     ]
                 )
+                if np.isnan(var_min) or np.isnan(var_max):
+                    raise ValueError(
+                        "The variable limits are set to 'fixed' but the min and max "
+                        "values are NaN"
+                    )
                 if var_min == var_max:
                     var_min -= 1
                     var_max += 1
@@ -435,8 +439,14 @@ class QuickPlot(object):
                 self.axis_limits[key] = [x_min, x_max, var_min, var_max]
             else:
                 self.variable_limits[key] = (var_min, var_max)
+            if (
+                var_min is not None
+                and var_max is not None
+                and (np.isnan(var_min) or np.isnan(var_max))
+            ):  # pragma: no cover
+                raise ValueError(f"Axis limits cannot be NaN for variables '{key}'")
 
-    def plot(self, t):
+    def plot(self, t, dynamic=False):
         """Produces a quick plot with the internal states at time t.
 
         Parameters
@@ -461,11 +471,6 @@ class QuickPlot(object):
         # initialize empty handles, to be created only if the appropriate plots are made
         solution_handles = []
 
-        if self.n_cols == 1:
-            fontsize = 30
-        else:
-            fontsize = 42 // self.n_cols
-
         for k, (key, variable_lists) in enumerate(self.variables.items()):
             ax = self.fig.add_subplot(self.gridspec[k])
             self.axes.append(ax)
@@ -479,7 +484,7 @@ class QuickPlot(object):
             # Set labels for the first subplot only (avoid repetition)
             if variable_lists[0][0].dimensions == 0:
                 # 0D plot: plot as a function of time, indicating time t with a line
-                ax.set_xlabel("Time [{}]".format(self.time_unit), fontsize=fontsize)
+                ax.set_xlabel("Time [{}]".format(self.time_unit))
                 for i, variable_list in enumerate(variable_lists):
                     for j, variable in enumerate(variable_list):
                         if len(variable_list) == 1:
@@ -493,7 +498,6 @@ class QuickPlot(object):
                         (self.plots[key][i][j],) = ax.plot(
                             full_t / self.time_scaling_factor,
                             variable(full_t, warn=False),
-                            lw=2,
                             color=self.colors[i],
                             linestyle=linestyle,
                         )
@@ -508,6 +512,7 @@ class QuickPlot(object):
                     ],
                     [y_min, y_max],
                     "k--",
+                    lw=1.5,
                 )
             elif variable_lists[0][0].dimensions == 1:
                 # 1D plot: plot as a function of x at time t
@@ -516,7 +521,6 @@ class QuickPlot(object):
                 spatial_var_name = list(spatial_vars.keys())[0]
                 ax.set_xlabel(
                     "{} [{}]".format(spatial_var_name, self.spatial_unit),
-                    fontsize=fontsize,
                 )
                 for i, variable_list in enumerate(variable_lists):
                     for j, variable in enumerate(variable_list):
@@ -530,32 +534,23 @@ class QuickPlot(object):
                         (self.plots[key][i][j],) = ax.plot(
                             self.first_dimensional_spatial_variable[key],
                             variable(t_in_seconds, **spatial_vars, warn=False),
-                            lw=2,
                             color=self.colors[i],
                             linestyle=linestyle,
                             zorder=10,
                         )
                         variable_handles.append(self.plots[key][0][j])
                     solution_handles.append(self.plots[key][i][0])
-                # add dashed lines for boundaries between subdomains
-                y_min, y_max = ax.get_ylim()
-                ax.set_ylim(y_min, y_max)
+                # add lines for boundaries between subdomains
                 for boundary in variable_lists[0][0].internal_boundaries:
                     boundary_scaled = boundary * self.spatial_factor
-                    ax.plot(
-                        [boundary_scaled, boundary_scaled],
-                        [y_min, y_max],
-                        color="0.5",
-                        lw=1,
-                        zorder=0,
-                    )
+                    ax.axvline(boundary_scaled, color="0.5", lw=1, zorder=0)
             elif variable_lists[0][0].dimensions == 2:
                 # Read dictionary of spatial variables
                 spatial_vars = self.spatial_variable_dict[key]
                 # there can only be one entry in the variable list
                 variable = variable_lists[0][0]
-                # different order based on whether the domains are x-r, x-z or y-z
-                if self.is_x_r[key] is True:
+                # different order based on whether the domains are x-r, x-z or y-z, etc
+                if self.x_first_and_y_second[key] is False:
                     x_name = list(spatial_vars.keys())[1][0]
                     y_name = list(spatial_vars.keys())[0][0]
                     x = self.second_dimensional_spatial_variable[key]
@@ -566,17 +561,9 @@ class QuickPlot(object):
                     y_name = list(spatial_vars.keys())[1][0]
                     x = self.first_dimensional_spatial_variable[key]
                     y = self.second_dimensional_spatial_variable[key]
-                    # need to transpose if domain is x-z
-                    if self.is_y_z[key] is True:
-                        var = variable(t_in_seconds, **spatial_vars, warn=False)
-                    else:
-                        var = variable(t_in_seconds, **spatial_vars, warn=False).T
-                ax.set_xlabel(
-                    "{} [{}]".format(x_name, self.spatial_unit), fontsize=fontsize
-                )
-                ax.set_ylabel(
-                    "{} [{}]".format(y_name, self.spatial_unit), fontsize=fontsize
-                )
+                    var = variable(t_in_seconds, **spatial_vars, warn=False).T
+                ax.set_xlabel("{} [{}]".format(x_name, self.spatial_unit))
+                ax.set_ylabel("{} [{}]".format(y_name, self.spatial_unit))
                 vmin, vmax = self.variable_limits[key]
                 # store the plot and the var data (for testing) as cant access
                 # z data from QuadMesh or QuadContourSet object
@@ -587,42 +574,59 @@ class QuickPlot(object):
                         var,
                         vmin=vmin,
                         vmax=vmax,
-                        cmap="coolwarm",
-                        shading="gouraud",
+                        shading='auto',
                     )
                 else:
                     self.plots[key][0][0] = ax.contourf(
-                        x, y, var, levels=100, vmin=vmin, vmax=vmax, cmap="coolwarm"
+                        x, y, var, levels=100, vmin=vmin, vmax=vmax
                     )
                 self.plots[key][0][1] = var
                 if vmin is None and vmax is None:
                     vmin = ax_min(var)
                     vmax = ax_max(var)
                 self.colorbars[key] = self.fig.colorbar(
-                    cm.ScalarMappable(
-                        colors.Normalize(vmin=vmin, vmax=vmax), cmap="coolwarm"
-                    ),
+                    cm.ScalarMappable(colors.Normalize(vmin=vmin, vmax=vmax)),
                     ax=ax,
                 )
             # Set either y label or legend entries
             if len(key) == 1:
                 title = split_long_string(key[0])
-                ax.set_title(title, fontsize=fontsize)
+                ax.set_title(title, fontsize="medium")
             else:
                 ax.legend(
                     variable_handles,
                     [split_long_string(s, 6) for s in key],
                     bbox_to_anchor=(0.5, 1),
-                    fontsize=8,
                     loc="lower center",
                 )
 
         # Set global legend
-        if len(solution_handles) > 0:
-            self.fig.legend(solution_handles, self.labels, loc="lower right")
+        if len(self.labels) > 1:
+            fig_legend = self.fig.legend(
+                solution_handles, self.labels, loc="lower right"
+            )
+            # Get the position of the top of the legend in relative figure units
+            # There may be a better way ...
+            try:
+                legend_top_inches = fig_legend.get_window_extent(
+                    renderer=self.fig.canvas.get_renderer()
+                ).get_points()[1, 1]
+                fig_height_inches = (self.fig.get_size_inches() * self.fig.dpi)[1]
+                legend_top = legend_top_inches / fig_height_inches
+            except AttributeError:  # pragma: no cover
+                # When testing the examples we set the matplotlib backend to "Template"
+                # which means that the above code doesn't work. Since this is just for
+                # that particular test we can just skip it
+                legend_top = 0
+        else:
+            legend_top = 0
 
         # Fix layout
-        bottom = 0.05 + 0.03 * max((len(self.labels) - 2), 0)
+        if dynamic:
+            slider_top = 0.05
+        else:
+            slider_top = 0
+        bottom = max(legend_top, slider_top)
         self.gridspec.tight_layout(self.fig, rect=[0, bottom, 1, 1])
 
     def dynamic_plot(self, testing=False, step=None):
@@ -643,21 +647,28 @@ class QuickPlot(object):
 
             step = step or self.max_t / 100
             widgets.interact(
-                self.plot,
-                t=widgets.FloatSlider(min=0, max=self.max_t, step=step, value=0),
+                lambda t: self.plot(t, dynamic=False),
+                t=widgets.FloatSlider(
+                    min=self.min_t, max=self.max_t, step=step, value=self.min_t
+                ),
                 continuous_update=False,
             )
         else:
             import matplotlib.pyplot as plt
             from matplotlib.widgets import Slider
 
-            # create an initial plot at time 0
-            self.plot(0)
+            # create an initial plot at time self.min_t
+            self.plot(self.min_t, dynamic=True)
 
             axcolor = "lightgoldenrodyellow"
             ax_slider = plt.axes([0.315, 0.02, 0.37, 0.03], facecolor=axcolor)
             self.slider = Slider(
-                ax_slider, "Time [{}]".format(self.time_unit), 0, self.max_t, valinit=0
+                ax_slider,
+                "Time [{}]".format(self.time_unit),
+                self.min_t,
+                self.max_t,
+                valinit=self.min_t,
+                color="#1f77b4",
             )
             self.slider.on_changed(self.slider_update)
 
@@ -683,25 +694,15 @@ class QuickPlot(object):
                         var = variable(
                             time_in_seconds,
                             **self.spatial_variable_dict[key],
-                            warn=False
+                            warn=False,
                         )
                         plot[i][j].set_ydata(var)
-                        var_min = min(var_min, np.nanmin(var))
-                        var_max = max(var_max, np.nanmax(var))
+                        var_min = min(var_min, ax_min(var))
+                        var_max = max(var_max, ax_max(var))
                 # update boundaries between subdomains
                 y_min, y_max = self.axis_limits[key][2:]
                 if y_min is None and y_max is None:
-                    y_min, y_max = ax_min(var_min), ax_max(var_max)
-                    ax.set_ylim(y_min, y_max)
-                    for boundary in self.variables[key][0][0].internal_boundaries:
-                        boundary_scaled = boundary * self.spatial_factor
-                        ax.plot(
-                            [boundary_scaled, boundary_scaled],
-                            [y_min, y_max],
-                            color="0.5",
-                            lw=1,
-                            zorder=0,
-                        )
+                    ax.set_ylim(var_min, var_max)
             elif self.variables[key][0][0].dimensions == 2:
                 # 2D plot: plot as a function of x and y at time t
                 # Read dictionary of spatial variables
@@ -709,18 +710,14 @@ class QuickPlot(object):
                 # there can only be one entry in the variable list
                 variable = self.variables[key][0][0]
                 vmin, vmax = self.variable_limits[key]
-                if self.is_x_r[key] is True:
+                if self.x_first_and_y_second[key] is False:
                     x = self.second_dimensional_spatial_variable[key]
                     y = self.first_dimensional_spatial_variable[key]
                     var = variable(time_in_seconds, **spatial_vars, warn=False)
                 else:
                     x = self.first_dimensional_spatial_variable[key]
                     y = self.second_dimensional_spatial_variable[key]
-                    # need to transpose if domain is x-z
-                    if self.is_y_z[key] is True:
-                        var = variable(time_in_seconds, **spatial_vars, warn=False)
-                    else:
-                        var = variable(time_in_seconds, **spatial_vars, warn=False).T
+                    var = variable(time_in_seconds, **spatial_vars, warn=False).T
                 # store the plot and the var data (for testing) as cant access
                 # z data from QuadMesh or QuadContourSet object
                 if self.is_y_z[key] is True:
@@ -730,22 +727,57 @@ class QuickPlot(object):
                         var,
                         vmin=vmin,
                         vmax=vmax,
-                        cmap="coolwarm",
-                        shading="gouraud",
+                        shading='auto',
                     )
                 else:
                     self.plots[key][0][0] = ax.contourf(
-                        x, y, var, levels=100, vmin=vmin, vmax=vmax, cmap="coolwarm"
+                        x, y, var, levels=100, vmin=vmin, vmax=vmax
                     )
                 self.plots[key][0][1] = var
                 if (vmin, vmax) == (None, None):
                     vmin = ax_min(var)
                     vmax = ax_max(var)
                     cb = self.colorbars[key]
-                    cb.update_bruteforce(
-                        cm.ScalarMappable(
-                            colors.Normalize(vmin=vmin, vmax=vmax), cmap="coolwarm"
-                        )
+                    cb.update_normal(
+                        cm.ScalarMappable(colors.Normalize(vmin=vmin, vmax=vmax))
                     )
 
         self.fig.canvas.draw_idle()
+
+    def create_gif(self, number_of_images=80, duration=0.1, output_filename="plot.gif"):
+        """
+        Generates x plots over a time span of max_t - min_t and compiles them to create
+        a GIF.
+
+        Parameters
+        ----------
+        number_of_images : int (optional)
+            Number of images/plots to be compiled for a GIF.
+        duration : float (optional)
+            Duration of visibility of a single image/plot in the created GIF.
+        output_filename : str (optional)
+            Name of the generated GIF file.
+
+        """
+        import imageio
+        import matplotlib.pyplot as plt
+
+        # time stamps at which the images/plots will be created
+        time_array = np.linspace(self.min_t, self.max_t, num=number_of_images)
+        images = []
+
+        # create images/plots
+        for val in time_array:
+            self.plot(val)
+            images.append("plot" + str(val) + ".png")
+            self.fig.savefig("plot" + str(val) + ".png", dpi=300)
+            plt.close()
+
+        # compile the images/plots to create a GIF
+        with imageio.get_writer(output_filename, mode="I", duration=duration) as writer:
+            for image in images:
+                writer.append_data(imageio.imread(image))
+
+        # remove the generated images
+        for image in images:
+            os.remove(image)
